You are viewing a plain text version of this content. The canonical link for it is here.
Posted to xap-commits@incubator.apache.org by mt...@apache.org on 2006/08/03 20:00:31 UTC

svn commit: r428506 - in /incubator/xap/trunk: WebContent/examples/dojo/datePicker.html src/xap/bridges/dojo/DojoDatePickerBridge.js src/xap/taghandling/plugin.xml

Author: mturyn
Date: Thu Aug  3 13:00:30 2006
New Revision: 428506

URL: http://svn.apache.org/viewvc?rev=428506&view=rev
Log:
Altered with the name of the Dojo DatePicker widget's bridge class, "xap.bridges.basic.DatePicker" to "xap.bridges.dojo.DojoDatePicker".

Modified:
    incubator/xap/trunk/WebContent/examples/dojo/datePicker.html
    incubator/xap/trunk/src/xap/bridges/dojo/DojoDatePickerBridge.js
    incubator/xap/trunk/src/xap/taghandling/plugin.xml

Modified: incubator/xap/trunk/WebContent/examples/dojo/datePicker.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/datePicker.html?rev=428506&r1=428505&r2=428506&view=diff
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/datePicker.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/datePicker.html Thu Aug  3 13:00:30 2006
@@ -28,7 +28,7 @@
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
 						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
-						"xap.bridges.basic.DatePickerBridge",
+						"xap.bridges.dojo.DojoDatePickerBridge",
 "src.dojo/src/widget.html.DatePicker"						
 							) ;
     </script>

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoDatePickerBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoDatePickerBridge.js?rev=428506&r1=428505&r2=428506&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/taghandling/plugin.xml (original)
+++ incubator/xap/trunk/src/xap/taghandling/plugin.xml Thu Aug  3 13:00:30 2006
@@ -29,7 +29,7 @@
 		
 		
 		<mapping class="xap.bridges.basic.DomNodeBridge" name="dom"/>
-		<mapping class="xap.bridges.basic.DatePickerBridge" name="datePicker"/>
+		<mapping class="xap.bridges.dojo.DojoDatePickerBridge" name="datePicker"/>
 										
 	</tag-mappings>
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoDatePickerBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoDatePickerBridge.js Thu Aug  3 13:00:30 2006
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-Xap.provide("xap.bridges.basic.DatePickerBridge");
+Xap.provide("xap.bridges.dojo.DojoDatePickerBridge");
 Xap.require("xap.util.LogFactory");
 Xap.require("xap.bridges.dojo.DojoWidgetBridge");
 Xap.require("dojo.widget.DatePicker");
@@ -26,49 +26,49 @@
  * A wrapper for a Dojo DatePicker, treated as a black box.
  */
 /**
- * Creates a xap.bridges.basic.DatePickerBridge.
+ * Creates a xap.bridges.dojo.DojoDatePickerBridge.
  * 
  * 
  * @class xap.bridges.basic.DatePickerBridge is the bridge between an XML element
  * representing a control and a subclass of DatePicker. This class 
  * is typically not used directly but is extended by other classes 
  * for its subclasses.
  * 
  * @author mturyn
  */
-xap.bridges.basic.DatePickerBridge = function(){
+xap.bridges.dojo.DojoDatePickerBridge = function(){
 	xap.bridges.dojo.DojoWidgetBridge.call(this);
 };
 
 Xap.setupClassAsSubclassOf(
-	"xap.bridges.basic.DatePickerBridge",
+	"xap.bridges.dojo.DojoDatePickerBridge",
 	"xap.bridges.dojo.DojoWidgetBridge"
 );
 
 
 
 
-xap.bridges.basic.DatePickerBridge.prototype._peer = null ;
+xap.bridges.dojo.DojoDatePickerBridge.prototype._peer = null ;
 
 
-xap.bridges.basic.DatePickerBridge.prototype.getPeerString = function(){
+xap.bridges.dojo.DojoDatePickerBridge.prototype.getPeerString = function(){
 	return "DatePicker" ;
 }
 
 
-xap.bridges.basic.DatePickerBridge.prototype.attributeSet = function(){
+xap.bridges.dojo.DojoDatePickerBridge.prototype.attributeSet = function(){
 	//TO_DO anything useful here?  format-string?
 };
 
 
-xap.bridges.basic.DatePickerBridge.prototype.getPeerOnCommandEvent = function(){
+xap.bridges.dojo.DojoDatePickerBridge.prototype.getPeerOnCommandEvent = function(){
 	return "onSelectDate" ;
 }
 
 
 // Just testing that the superclass event-mapper doesn't destroy any explicitly-defined 
 // events:
-xap.bridges.basic.DatePickerBridge.prototype.onIncrementYear = function(){
+xap.bridges.dojo.DojoDatePickerBridge.prototype.onIncrementYear = function(){
 	this.fireEvent("onIncrementYear") ;
 	var bkpt = true ;
 }
@@ -26,49 +26,49 @@
  * 
  * 
- * @class xap.bridges.basic.DatePickerBridge is the bridge between an XML element
+ * @class xap.bridges.dojo.DojoDatePickerBridge is the bridge between an XML element
  * representing a control and a subclass of DatePicker. This class 
  * is typically not used directly but is extended by other classes 

Modified: incubator/xap/trunk/src/xap/taghandling/plugin.xml
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/taghandling/plugin.xml?rev=428506&r1=428505&r2=428506&view=diff
==============================================================================